/**
 * <p>File: TestSystemSolver.java</p>
 * <p>Title: Numerical methods</p>
 * <p>Description: Course on numerical analysis</p>
 * <p>Date: April 2022</p>
 * @author Faton M. Berisha
 * @version 7.0.0
 */

import numeric.*;

public class TestSystemSolver {
	public static void main(String[] args) {
		double[] initial = { 0.1, 0.1, -0.1 };
		SystemSolver solver = new SystemSolver(initial.length);

		// Example 10.1.2
		solver.setTolerance(1E-8);
		solver.setNumIterations(20);
		SystemDemoView.setNumSignificantDigits(8);
		MultivariateFunction[] gi = {
			x -> Math.cos(x[1] * x[2]) / 3.0 + 1.0 / 6.0,
			x -> Math.sqrt(x[0] * x[0] + Math.sin(x[2]) + 1.06) / 9.0 - 0.1,
			x -> -Math.exp(-x[0] * x[1]) / 20.0 - (10 * Math.PI - 3) / 60.0
		};
		VectorValued g = new VectorFunction(gi);
		new SystemDemoView("Metoda e piks fikse", solver);
		try {
			solver.fixedPoint(g, initial);
		} catch (ArithmeticException e) {
		}

		// Example 10.1.3
		
		MultivariateFunction[] fi = {
			x -> 3 * x[0] - Math.cos(x[1] * x[2]) - 1.0 / 2.0,
			x -> x[0] * x[0] - 81 * (x[1] + 0.1) * (x[1] + 0.1)
				+ Math.sin(x[2]) + 1.06,
			x -> Math.exp(-x[0] * x[1]) + 20 * x[2]
						+ (10 * Math.PI - 3) / 3
		};
		MultivariateFunction[][] df = {
			{ x -> 3, x -> x[2] * Math.sin(x[1] * x[2]), x -> x[1] * Math.sin(x[1] * x[2]) },
			{ x -> 2 * x[0], x -> -162 * (x[1] + 0.1), x -> Math.cos(x[2]) },
			{ x -> -x[1] * Math.exp(-x[0] * x[1]), x -> -x[0] * Math.exp(-x[0] * x[1]), x -> 20 }
		};
		DifferentiableVectorValued f = new DifferentiableVectorFunction(fi, df);
		new SystemDemoView("Metoda e Newton-it", solver);
		try {
			solver.newton(f, initial);
		} catch (ArithmeticException e) {
			System.err.println(e.getMessage());
		}

	}
}
