/**
 * <p>File: DifferentiableFunction.java</p>
 * <p>Title: Numerical methods</p>
 * <p>Description: Course on numerical analysis</p>
 * <p>Date: January 2016</p>
 * @author Faton M. Berisha
 * @version 6.0.0
 */

package numeric;

import java.text.*;

/**
 * Writes a matrix.
 */
public class MatrixWriter {

	private Matrix matrix;
	private String pattern = "0.00";

	/**
	 * Constructs matrix writer.
	 * 
	 * @param matrix
	 *            the matrix to be written
	 */
	public MatrixWriter(Matrix matrix) {
		this.matrix = matrix;
	}

	/**
	 * Gets the <code>DecimalFormat</code> pattern for the matrix elements.
	 * 
	 * @return the pattern string
	 */
	public String getPattern() {
		return pattern;
	}

	/**
	 * Sets the <code>DecimalFormat</code> pattern for the matrix elements.
	 * 
	 * @param pattern
	 *            the pattern string
	 */
	public void setPattern(String pattern) {
		this.pattern = pattern;
	}

	/**
	 * Writes the matrix.
	 */
	public void writeMatrix() {
		int rows = matrix.getNumRows();
		int cols = matrix.getNumCols();
		DecimalFormat formatter = new DecimalFormat(pattern);
		System.out.print('{');
		boolean firstRow = true;
		for (int i = 0; i < rows; i++) {
			if (firstRow) {
				System.out.print('{');
				firstRow = false;
			} else {
				System.out.print(",\n {");
			}
			boolean firstCol = true;
			for (int j = 0; j < cols; j++) {
				String val = formatter.format(matrix.get(i, j));
				if (firstCol) {
					firstCol = false;
				} else {
					System.out.print(", ");
				}
				System.out.print(val);
			}
			System.out.print('}');
		}
		System.out.println('}');
	}

}
