/**
 * <p>File: DifferentiableFunction.java</p>
 * <p>Title: Numerical methods</p>
 * <p>Description: Course on numerical analysis</p>
 * <p>Date: January 2016</p>
 * @author Faton M. Berisha
 * @version 6.0.0
 */

package numeric;

import java.awt.Point;
import java.util.*;
import javax.swing.*;

/**
 * A demo view for system solving iterative method.
 */
public class SystemDemoView extends AbstractIterationTable implements Observer {

	private static final long serialVersionUID = 4;

	private Solver solver;
	private int currentIteration = 0;

	private static Point frameLocation = new Point();
	private static int offset = 20;

	/**
	 * Constructs a demo view with title for system solving iterative method.
	 * 
	 * @param frameTitle
	 *            the title of the frame
	 * @param solver
	 *            the system solver
	 */
	public SystemDemoView(String frameTitle, Solver solver) {
		this.solver = solver;
		int numVariables = solver.getNumVariables();
		columnHeader = new String[numVariables + 1];
		columnHeader[0] = "k";
		for (int i = 1; i <= numVariables; i++) {
			columnHeader[i] = "x" + i + "(k)";
		}
		data = new Object[solver.getNumIterations() + 1][solver
				.getNumVariables() + 1];

		JTable table = new JTable(this);
		JScrollPane sp = new JScrollPane(table);
		JFrame frame = new JFrame(frameTitle);
		frame.getContentPane().add(sp);
		frame.pack();
		frame.setLocation(frameLocation);
		frameLocation.translate(offset, offset);
		frame.setVisible(true);

		table.setDefaultRenderer(Double.class,
				new AbstractTable.DoubleRenderer());

		solver.addSolutionObserver(this);
	}

	/**
	 * Constructs a demo view for system solving iterative method.
	 * 
	 * @param solver
	 *            the system solver
	 */
	public SystemDemoView(Solver solver) {
		this("Tabela e iterimeve", solver);
	}

	public int getColumnCount() {
		return solver.getNumVariables() + 1;
	}

	public int getRowCount() {
		return currentIteration;
	}

	public void update(Observable o, Object arg) {
		data[currentIteration][0] = new Integer(currentIteration);
		if (arg instanceof Matrix) {
			int numVariables = getColumnCount() - 1;
			for (int i = 0; i < numVariables; i++) {
				data[currentIteration][i + 1] = new Double(((Matrix) arg).get(
						i, 0));
			}
		}
		fireTableDataChanged();
		currentIteration++;
	}

}
